/* Copyright (c) 2015 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 * @defgroup pwm_example_main main.c
 * @{
 * @ingroup pwm_example
 * 
 * @brief  PWM Example Application main file.
 *
 * This file contains the source code for a sample application using PWM.
 *
 *
 */

#include <stdbool.h>
#include <stdint.h>
#include "nrf.h"
#include "app_error.h"
#include "bsp.h"
#include "nrf_delay.h"
#include "app_pwm.h"

#define PWM_OUTPUT1 7
#define PWM_OUTPUT2 6

APP_PWM_INSTANCE(PWM1,1);                   // Create the instance "PWM1" using TIMER1.

static volatile bool ready_flag;            // A flag indicating PWM status.

void pwm_ready_callback(uint32_t pwm_id)    // PWM callback function
{
    ready_flag = true;
}

/**
 * Initialize all four LEDs on the nRF51 DK.
 */
void init_gpio()
{
    
		nrf_gpio_range_cfg_output(6,7);
	  nrf_gpio_pin_dir_set(6, NRF_GPIO_PIN_DIR_OUTPUT);
	  NRF_GPIO->PIN_CNF[6] = (GPIO_PIN_CNF_DRIVE_H0D1 << GPIO_PIN_CNF_DRIVE_Pos);
    nrf_gpio_pin_clear(6);
	  nrf_gpio_pin_dir_set(7, NRF_GPIO_PIN_DIR_OUTPUT);
	  NRF_GPIO->PIN_CNF[7] = (GPIO_PIN_CNF_DRIVE_H0D1 << GPIO_PIN_CNF_DRIVE_Pos);
    nrf_gpio_pin_clear(7);                                                                                                                                  
}	
static void PWMinit(void)
{
	ret_code_t err_code;
  app_pwm_config_t pwm1_cfg = APP_PWM_DEFAULT_CONFIG_2CH(160UL,6,7);//6.3KHz
  pwm1_cfg.pin_polarity[1] = APP_PWM_POLARITY_ACTIVE_LOW;
	
	/* Initialize and enable PWM. */
    err_code = app_pwm_init(&PWM1,&pwm1_cfg,pwm_ready_callback);
    APP_ERROR_CHECK(err_code);
	
    app_pwm_enable(&PWM1);
    for(int i = 0; i < 3; i++)
{
    app_pwm_channel_duty_set(&PWM1, 0, 50);
    nrf_delay_ms(1000);
    app_pwm_channel_duty_set(&PWM1, 0, 0);
    nrf_delay_ms(2000);
	  app_pwm_channel_duty_set(&PWM1, 0, 50);
}
 app_pwm_disable(&PWM1);
}

int main(void)
{
	  init_gpio();
    PWMinit();
}


/** @} */
